Guide de création d'un outil d'évaluation des risques  
=====================================================

Vous cherchez à développer le contenu de l'outil numérique d'évaluation des risques spécifique à votre domaine d'activité et à le proposer aux entreprises de votre secteur.

Avant de vous lancer dans la création d'un outil d'évaluation des risques, il est conseillé de commencer par réfléchir à certaines questions.  Cela vous fera gagner du temps car vous n'aurez pas à apporter de nombreuses modifications par la suite. Les utilisateurs finaux de l'outil gagneront eux aussi du temps en pratique. Les aspects suivants méritent réflexion.

1. La structure et le contenu de l'outil d'évaluation des risques relativement à l'utilisateur final:

   1. l’outil d’évaluation des risques va être utilisé par un entrepreneur ou le collaborateur d'une entreprise. La structure de l'outil doit donc être aussi adaptée que possible aux modes de réflexion et aux activités quotidiennes des collaborateurs de ces entreprises; 
   2. le langage de l'outil doit être facile à comprendre par tous. 

2. La structure d'un outil d'évaluation des risques relativement à son usage. Par structure, il faut entendre:

   1. l'élaboration d'un profil dans l'outil. Un profil détermine les modules auxquels l'utilisateur aura accès (l'utilisateur coche en effet certaines cases concernant l'usage de l'outil d'évaluation des risques lorsqu’il commence à le remplir); 
   2. une seule entreprise avec plusieurs lieux d'implantation. Cette option permet de créer des profils pour chaque lieu d'implantation; 
   3. divers types de modules. En indiquant qu'un module est un «module de stratégie», un «module d'inspection» ou un «module de questions aux employés», seuls les modules requis sont affichés; 
   4. les modules qui commencent par une question de sélection. Les questions de sélection déterminent si le contenu du module concerne ou non l'entreprise en question; 
   5. les modules avec des séries de questions axées sur un sujet particulier. Un module peut contenir des sous-modules.

La structure et le contenu de l'outil d'évaluation des risques relativement à l'utilisateur final
-------------------------------------------------------------------------------------------------

La structure relativement à l'utilisateur final 
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Qui est l'utilisateur final et que cela signifie-t-il pour la structure de l'outil d'évaluation des risques? Il est important de tenir compte de la tendance de l'utilisateur final à réfléchir selon les processus propres à son métier. Il pense dans son propre langage et fait donc référence aux choses par des termes qu'il connaît bien: essayez d'en tenir compte autant que possible.

Dans la pratique, ce langage est souvent différent de celui de la personne qui crée le contenu des outils d'évaluation des risques. Le mode de réflexion de cette personne est lui aussi influencé par des processus propres à son métier, et le langage qu’elle utilise lui est propre.

L'utilisateur final est essentiel: il doit pouvoir utiliser l'outil d'évaluation des risques à ses propres fins sans aucun problème ni aucune difficulté d'interprétation. Voici quelques exemples:

* l'utilisateur final pense au travail physique, tandis que l'expert pense à la charge physique; 
* l'utilisateur final pense au travail sous la chaleur ou dans le froid, tandis que l'expert pense à l'environnement thermique; 
* l'expert pense à la sécurité et crée un module contenant tout ce qui concerne ce domaine. L'utilisateur final peut envisager, par exemple, d’ouvrir ou de fermer un magasin, et de réfléchir à ce que cela implique. Il peut également réfléchir à la façon de prendre en charge un client agressif. 

Il est important de structurer l'outil de telle sorte qu'il corresponde à la manière dont l'utilisateur final type pense et agit. Cela rend le contenu reconnaissable et facilite l'exécution d'un plan d'action. 

Une structure bien pensée s'avère avantageuse par la suite. Veillez donc à classifier les rubriques dans un ordre correspondant aux besoins des utilisateurs finaux. Veuillez noter que ces classifications diffèrent généralement de la manière dont les experts pourraient normalement les envisager. L'outil de base à partir duquel vous pouvez créer des variations contient les modules suivants. Dans le manuel consacré au système de gestion du contenu (SGC), vous trouverez de plus amples renseignements sur le contenu et sur la manière de l'utiliser comme base.

1. Chaque bâtiment
2. Quelques bâtiments 
3. Aire de stockage / entrepôt 
4. Travail de bureau 
5. Livraison et enlèvement des matériaux 
6. Travail physique 
7. Travail sur site 
8. Travail avec les clients 
9. Bruit 
10. Climat: chaleur, rayonnement, froid, plein air 
11. Vibrations 
12. Substances dangereuses en tant que matières premières 
13. Substances dangereuses résultant du travail / pendant le travail 
14. Hauteurs / espaces confinés / espaces fermés 
15. Outils / machines / modes de transport 
16. En cas d'urgence 
17. Temps de travail et de repos 
18. Tâches / fonctions des employés 
19. Comportement indésirable des employés 
20. Accords de base concernant la santé et la sécurité au travail 
21. Informations 
22. Accords relatifs à l'absence au travail 
23. Accidents 
24. Progression du plan d'action 
25. Organisation des mesures préventives

    * Obligations de prévention

26. Programme sur mesure / programme de protection

    * Programme sur mesure 
    * Programme de protection


Le contenu relativement à l'utilisateur final 
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Le langage 
++++++++++

Le contenu de l'outil doit être facile à comprendre par tous. Cela signifie que vous devez réfléchir attentivement - sans perdre l'utilisateur final de vue - au type de langage utilisé. Il est important d'utiliser un langage parlé plutôt qu'écrit. L'utilisateur final doit pouvoir comprendre immédiatement ce qui est écrit et être capable de réagir en conséquence. En outre, il est conseillé d'éviter les phrases de plus de dix mots. Ne perdez pas de vue les besoins de l'utilisateur final! Des phrases courtes, dans un langage de tous les jours pouvant être facilement lu par des non-initiés, éviteront de développer une certaine aversion de la part de l'utilisateur final. Elles lui permettront de dresser un inventaire et d'utiliser correctement l'outil d'évaluation des risques.

Questions/propositions 
++++++++++++++++++++++ 

L'outil fonctionne avec des «propositions» plutôt qu'avec des «questions». La structure du contenu de l'outil d'évaluation des risques repose sur des propositions. 

* Une situation (la proposition) est «régulière» ou «irrégulière»; la réponse est un «oui» ou un «non» clair. 
* Si une situation (la proposition) n'est pas régulière, l'objet (la proposition) est inclus dans le plan d'action. 

Le texte de la proposition dans la situation donnée (régulière ou non) est le même que le texte dans le plan d'action. Elle devient alors la situation à atteindre. Lorsqu'une réponse a déjà été donnée à une situation particulière, la formulation est familière. 

En plus d'être connu de l'utilisateur final, cela a pour autre avantage, du point de vue de la personne chargée de l'élaboration du contenu, que la situation n'a besoin d'être décrite qu'une seule fois. Si des changements (réglementaires) doivent être apportés à l'outil ultérieurement, ils n'auront besoin d'être mis en œuvre qu'une seule fois.

Il est également possible de sélectionner une option différente dans l'instrument:

* phase d'identification: des déclarations/questions dont la réponse peut être «oui» ou «non»; 
* phase d'évaluation: une déclaration qui peut être évaluée; 
* phase du plan d'action: la même déclaration mais à la forme négative.

Par exemple, «le bâtiment n'est pas sans amiante.»

Dans les deux cas, il est possible de clarifier les déclarations. Par exemple, il peut s'agir d'une explication des raisons pour lesquelles il est important de faire attention à une rubrique et/ou de ce qui peut être fait pour résoudre un problème. Des photographies, diagrammes et liens peuvent aussi être joints à chaque rubrique.

Éviter les déclarations négatives dans les propositions 
+++++++++++++++++++++++++++++++++++++++++++++++++++++++

En principe, les seules réponses possibles aux propositions sont «oui» et «non». Par conséquent, il est important d’éviter les déclarations négatives dans les propositions. Par exemple: «il n'y a pas d'amiante dans le bâtiment». Dans la pratique, l'utilisateur final ne sera pas sûr si son «oui» ou «non» sera interprété comme un accord ou un désaccord avec la proposition. On ne pourra donc pas établir clairement s'il y a ou non de l'amiante dans le bâtiment. Une reformulation de la proposition sans utiliser de négative donnerait «le bâtiment est sans amiante». «Oui» - la situation est régulière et ne figurera pas dans le plan d'action. «Non» - la situation est irrégulière (autrement dit, il y a de l'amiante dans le bâtiment) et diverses situations pourront figurer dans le plan d'action.


La structure de l'outil d'évaluation des risques relativement à son usage 
-------------------------------------------------------------------------

Cette section traite des aspects suivants:

1. création d'un profil dans l'outil. Le profil détermine quels modules concerneront l'utilisateur de l'outil d'évaluation des risques (parce que l'utilisateur répond à certaines questions lors du lancement de l'outil numérique d'évaluation des risques); 
2. savoir indiquer des lieux d'implantation multiples pour une même entreprise. Cette option permet de créer des profils pour chaque lieu d'implantation; 
3. les divers types de modules. Indiquer qu'un module est un «module de stratégie», un «module d'inspection» ou un «module de questions aux employés» signifie que seuls les modules requis sont affichés dans les lieux d'implantation où ils sont requis; 
4. les modules qui commencent par une question de filtrage. Les questions de filtrage déterminent si le contenu du module concerne l'entreprise en question; 
5. les modules avec des séries de questions axées sur un sujet particulier. Un module peut contenir des sous-modules.


Le profil 
~~~~~~~~~

Lorsque vous utilisez une question de profilage, vous examinez divers aspects des entreprises et de leurs activités éventuelles. L'utilisateur final de l'outil répond à plusieurs questions avant d'appliquer l'outil d'évaluation des risques. Les réponses à ces questions déterminent à quels modules l'utilisateur final aura ou non accès. Voici un exemple dans le secteur de la poissonnerie.

* Possédez-vous un magasin? 
* Possédez-vous un étal de marché? 
* Possédez-vous un véhicule de vente ambulante?

Des situations analogues peuvent se produire dans votre secteur d'activité. Il est également possible que certaines des entreprises transportent elles-mêmes leurs marchandises jusqu'à leurs clients, tandis que d'autres confient ces activités à des sous-traitants. Lorsque la pertinence du profil est établie à l'avance, l'utilisateur final n'a pas besoin de se préoccuper des modules qui ne concernent pas son entreprise.

Une entreprise avec plusieurs lieux d'implantation 
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Si un secteur d'activité est caractérisé par le fait que les entreprises ont plusieurs lieux d'implantation, il convient de l'indiquer au préalable dans l'instrument. Si vous désignez les lieux par leurs noms respectifs (lieu A, lieu B), l'utilisateur peut alors regrouper les évaluations des risques pour chaque lieu en une seule évaluation des risques.

Pour chaque lieu, l'utilisateur peut indiquer les activités effectuées en répondant aux questions de profilage. Seuls les modules concernant chaque lieu seront présents.

Divers types de modules 
~~~~~~~~~~~~~~~~~~~~~~~ 

Il existe trois types de modules:

1. les modules comprenant des questions administrative 
2. les modules comprenant des questions d'inspection 
3. les modules comprenant des questions aux employés

Modules comprenant des questions administratives 
++++++++++++++++++++++++++++++++++++++++++++++++ 

Les questions administratives concernent les «accords de base». Voici un exemple de question administrative: «Lors de l’achat de matériel, les exigences en matière de santé et sécurité au travail sont-elles prises en compte?» Il est possible de répondre à ce type de questions depuis un bureau, pour ainsi dire. Si une entreprise possède plusieurs lieux d'implantation, il est possible de stipuler que les questions de ce type (dans une rubrique «Accords de base concernant la santé et la sécurité au travail», par exemple) ne nécessitent qu'une seule réponse de l'entreprise, celle du siège social.

Modules comprenant des questions d'inspection 
+++++++++++++++++++++++++++++++++++++++++++++ 

Ces modules contiennent des questions concernant les risques réels et sont liés au travail effectué. Afin de pouvoir répondre aux questions de ces modules, il est souvent nécessaire d'inspecter le lieu travail. Le travail physique et le travail de bureau sont deux exemples de ce type de module. Dans le cas d'entreprises avec plusieurs lieux d'implantation, des questions de profilage peuvent être utilisées pour établir le type de travail effectué sur chacun des sites. Par exemple, si l'un d'eux n'a pas d'entrepôt, le module consacré aux entrepôts ne figurera pas pour ce lieu.

Modules comprenant des questions de l'employeur 
+++++++++++++++++++++++++++++++++++++++++++++++ 

Ce type de module diffère totalement des modules décrits précédemment. Il est possible d'indiquer dans l'outil d'évaluation des risques que certaines questions doivent être posées spécifiquement aux employés dans les cas où ils sont exposés à des risques majeurs. Leurs réponses peuvent être utilisées aux fins d'une évaluation des risques de qualité. Étant donné que ce type de module est différent des autres, il ne figure pas dans la liste de base des modules, mais apparaît avant le début de l'inventaire.

Les modules comprenant les questions administratives et les questions d'inspection comportent une description générale de leur contenu. Dès que l'utilisateur final commence à répondre aux questions, le contenu est immédiatement reconnaissable.

Questions de filtrage 
~~~~~~~~~~~~~~~~~~~~~

Une question de filtrage est la première question d'un module. Elle détermine si une situation est pertinente. Si la réponse à la question est «non», les questions suivantes du module ne sont pas affichées. Les modules comportant des questions de filtrage peuvent également être utiles dans certaines situations. Exemple de question de filtrage: «il y a un entrepôt ou une aire de stockage». Cela empêche l'utilisateur final d'avoir à répondre à des questions dans des modules qui ne s'appliquent pas à son entreprise.

Il est possible de travailler avec à la fois des questions de profilage et des questions de filtrage. 

Modules principaux et sous-modules 
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Un autre moyen d’établir une structure consiste à utiliser des modules principaux contenant des sous-modules. Le plus important est de veiller à ce que l'utilisateur final n'ait aucun mal à effectuer l'évaluation des risques. Vous pouvez commencer les sous-modules avec une question de filtrage afin de déterminer si le sous-module est pertinent.

Par exemple::

  Module principal:                                    Bâtiment 
    Sous-module:                                       Chaque bâtiment et les questions concernant ce bâtiment 
    Sous-module:                                       Certains bâtiments 
    En commençant par une question de filtrage:        Le public est accueilli dans le bâtiment et les 
                                                       questions concernant l'accueil du public 
    Sous-module:                                       Certains bâtiments 
    En commençant par une question de filtrage:        Il y a des escaliers, des escaliers roulants, des 
                                                       ascenseurs dans le bâtiment, suivie des questions 
                                                       portant sur ce sujet 
    Sous-module:                                       Certains bâtiments 
    Sous-module avec une question de filtrage:         Il y a des cuisines dans le bâtiment, suivie des 
                                                       questions portant sur ce sujet


Pour finir 
----------

Vous avez maintenant une idée de la méthode à suivre pour élaborer le contenu de l'outil numérique d'évaluation des risques. En mettant au point une structure: 

* adaptée à la manière dont l'utilisateur final pense et agit; 
* comprenant tous les thèmes qui, du point de vue de la santé et de la sécurité au travail, doivent figurer dans la structure, et de telle manière que l'utilisateur final puisse facilement les comprendre, vous aiderez l'utilisateur final à terminer l'outil numérique d'évaluation des risques. 

L'outil numérique d'évaluation des risques peut être utilisé à d'autres fins également, par exemple pour fournir des explications et des solutions plus détaillées, des liens vers des sites internet ou pour ajouter des photographies.  Pour en savoir plus sur ces autres usages, veuillez vous reporter au manuel consacré au système de gestion du contenu.

